#! /usr/bin/env python
# -*- encoding:utf-8 -*-
# FileName: c.py

"中国法定假日计算"

__author__   = "yetist"
__copyright__= "Copyright (C) 2019-2021 yetist <yetist@yetibook>"
__license__  = """
This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this library; if not, see <http://www.gnu.org/licenses/>.
"""
import gi
from gi.repository import GLib

vacations = ['-18122901', '18123003', '19020407', '-19020201', '-19020301', '19040503', '19050104', '-19042801', '-19050501', '19060703', '19091303', '19100107', '-19092901', '-19101201']

vacation_days = []
work_days = []
for i in vacations:
    ymd = abs(int(i))
    year = 2000 + int(ymd / 1000000)
    month = int(ymd % 1000000 / 10000)
    day = int(ymd % 10000 / 100)

    date = GLib.Date.new_dmy(day, month, year)
    count = ymd % 100
    for j in range(count):
        yid = int(date.get_year())%100
        did = date.get_day_of_year()
        out = yid * 1000 + did
        if int(i) < 0:
            work_days.append(out)
        else:
            vacation_days.append(out)
        date.add_days(1)
print('vacation days:', vacation_days)
print('work days:', work_days)



#! /usr/bin/env python
# -*- encoding:utf-8 -*-
# FileName: table2code.py

"This file is part of lunar-date"

__author__   = "yetist"
__copyright__= "Copyright (C) 2019-2021 yetist <yetist@yetibook>"
__license__  = """
This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this library; if not, see <http://www.gnu.org/licenses/>.
"""

import toml

class Table(object):
    def __init__ (self, file):
        self.file = file
        self.data = None

    def load(self):
        fp = open(self.file)
        self.data = toml.load(fp)
        self.lst = list(self.data.keys())
        self.lst.sort()
        self.start = self.lst[0]
        self.end = self.lst[-1]
        self.count = len(self.lst)

    def get_year_info(self, year):
        year_data = self.data[year]
        info = 0
        if year_data['leap_days'] == 30:
            info += 1
        for i in year_data['days']:
            info = info << 1
            if i == 30:
                info |= 1
            else:
                info |= 0
        info = info << 4
        info += year_data['leap']
        #print(bin(info), info, hex(info))
        return hex(info)

    def get_fest(self, year):
        year_data = self.data[year]
        return year_data['jie']

    def gen_year_info(self):
        header="""
long years_info[NUM_OF_YEARS] = {
	/* encoding:
	 *
	 * b      bbbbbbbbbbbb bbbb
	 * bit#	1 111111000000 0000
	 *      6 543210987654 3210
	 *      . ............ ....
	 * month# 000000000111
	 *      M 123456789012 L

	b_j = 1 for long month, b_j = 0 for short month
	L is the leap month of the year if 1<=L<=12; NO leap month if L = 0.
	The leap month (if exists) is long one iff M = 1.
	*/
"""
        print(header)
        for i in self.lst:
            val = self.get_year_info(i)
            if int(i) % 5 == 0:
                print("{}  /* {} */".format(val, i), end = '\n')
            elif int(i) % 5 == 1:
                print("        {},".format(val), end = ' ')
            elif int(i) % 5 == 4:
                print("{} ".format(val), end = ' ')
            else:
                print("{},".format(val), end = ' ')
        print("  /* {} */".format(i), end = '\n};\n\n')

    def gen_fest(self):
        print("static gchar fest[NUM_OF_YEARS][%d] = {" % self.count)
        for i in self.lst:
            print("{", end = ' ')
            jie_lst = [ str(x) for x in self.get_fest(i)]
            x = ', '.join(jie_lst)
            print(x, end = ' ')
            print("},   /* %s */" % str(i))
        print('};\n\n')

if __name__=="__main__":
    t = Table("table.toml")
    t.load()
    t.gen_year_info()
    t.gen_fest()



#!/usr/bin/python
# coding=utf-8

import gi
gi.require_version('LunarDate', '3.0')
from gi.repository import LunarDate
import sys
import locale
locale.setlocale(locale.LC_ALL, "")

def test_date():
    l = LunarDate.Date()
    l.set_solar_date(2010, 4, 2, 18)
    format={"a":"%(YEAR)年%(MONTH)月%(DAY)日%(HOUR)时",
            "b": "%(year)年%(month)月%(day)日%(hour)时",
            "c": "%(NIAN)年%(YUE)月%(RI)日%(SHI)时",
            "d": "%(nian)年%(yue)月%(ri)日%(shi)时",
            "e": "%(Y60)年%(M60)月%(D60)日%(H60)时",
            "f": "%(Y8)年%(M8)月%(D8)日%(H8)时",
            "g": "生肖属%(shengxiao)"}
    for i in ("a","b","c","d","e","f"):
        print(format[i],"\t"*2, l.strftime(format[i]))
    l.free()

test_date()
